function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React, { useState } from 'react';
import { Walktour } from '@rocketsoftware/walktour';
import TourTooltip from '../TourTooltip';
import PropTypes from 'prop-types';

var Tour = function Tour(_ref) {
  var flippedTitle = _ref.flippedTitle,
      flippedDescription = _ref.flippedDescription,
      enableFlip = _ref.enableFlip,
      flipBeforeCloseProp = _ref.flipBeforeClose,
      onClose = _ref.onClose,
      other = _objectWithoutProperties(_ref, ["flippedTitle", "flippedDescription", "enableFlip", "flipBeforeClose", "onClose"]);

  var _useState = useState(false),
      _useState2 = _slicedToArray(_useState, 2),
      flipped = _useState2[0],
      setFlipped = _useState2[1];

  return React.createElement(Walktour, _extends({}, other, {
    customCloseFunc: function customCloseFunc(logic) {
      if (onClose) {
        onClose(logic.stepIndex);
      }

      logic.close();
    },
    customTooltipRenderer: function customTooltipRenderer(logic) {
      var _logic$stepContent = logic.stepContent,
          title = _logic$stepContent.title,
          description = _logic$stepContent.description,
          disableNext = _logic$stepContent.disableNext,
          disablePrev = _logic$stepContent.disablePrev,
          hideNext = _logic$stepContent.hideNext,
          hidePrev = _logic$stepContent.hidePrev,
          hideClose = _logic$stepContent.hideClose,
          nextLabel = _logic$stepContent.nextLabel,
          prevLabel = _logic$stepContent.prevLabel,
          flipBeforeClose = _logic$stepContent.flipBeforeClose;
      return React.createElement(TourTooltip, _extends({}, enableFlip && {
        enableFlip: true,
        flipped: flipped,
        onFlip: function onFlip() {
          return setFlipped(!flipped);
        }
      }, {
        flippedTitle: flippedTitle,
        flippedDescription: flippedDescription
      }, other, {
        flipBeforeClose: flipBeforeClose || flipBeforeCloseProp,
        onNext: logic.next,
        onPrev: logic.prev,
        onClose: logic.close,
        description: description,
        title: title,
        disableNext: disableNext,
        disablePrev: disablePrev,
        hideNext: hideNext,
        hidePrev: hidePrev,
        hideClose: hideClose,
        nextLabel: nextLabel,
        prevLabel: prevLabel
      }));
    }
  }));
};

Tour.propTypes = {
  /**
   * An array of steps that the tour should follow
   */
  steps: PropTypes.arrayOf(PropTypes.shape({
    selector: PropTypes.string,
    description: PropTypes.string.isRequired,
    title: PropTypes.string,
    nextLabel: PropTypes.string,
    prevLabel: PropTypes.string,
    disableNext: PropTypes.bool,
    disablePrev: PropTypes.bool,
    hideNext: PropTypes.bool,
    hidePrev: PropTypes.bool,
    hideClose: PropTypes.bool,
    customNextFunc: PropTypes.func,
    customPrevFunc: PropTypes.func,
    disableAutoScroll: PropTypes.bool,
    disableSmoothScroll: PropTypes.bool,
    movingTarget: PropTypes.bool,
    maskPadding: PropTypes.number,
    tooltipSeparation: PropTypes.number,

    /**
     * Optionally cause the tour to advance to the next step upon clicking the targeted element.
     * Only buttons are supported.
     */
    nextOnTargetClick: PropTypes.bool,

    /**
     * Validate before advancing the tour after clicking a button. Expects a promise resolving to a boolean.
     */
    validateNextOnTargetClick: PropTypes.func,
    orientationPreferences: PropTypes.oneOf(['east', 'east-north', 'east-south', 'south', 'south-east', 'south-west', 'west', 'west-north', 'west-south', 'north', 'north-east', 'north-west']),

    /**
     * If specified, the tour will try to target and position with respect to an element that is outside
     * of its parent container. The tour is still bound to its container, so this should only be used
     * sparingly in situations where it cannot be avoided.
     */
    allowForeignTarget: PropTypes.bool
  })).isRequired,

  /** Optionally specify a custom close function for the entire tour. Passed the current step index as a param.
   */
  onClose: PropTypes.func,

  /**
   * Optionally specify the starting step. If conditionally rendering ({showTour && <Tour... />})
   * this can be used to resume from a particular step, even after unmounting.
   */
  initialStepIndex: PropTypes.number,

  /**
   * Optionally specify whether the tour should update upon changes to the target's size or position.
   */
  movingTarget: PropTypes.bool,

  /**
   * Optional identifier to differentiate between multiple tours on the same page.
   */
  identifier: PropTypes.string,

  /**
   * Optionally specify whether the mask should be disabled
   */
  disableMask: PropTypes.bool,

  /**
   * Optionally disable automatic scrolling
   */
  disableAutoScroll: PropTypes.bool,

  /**
   * Optionally disable smooth scrolling
   */
  disableSmoothScroll: PropTypes.bool,

  /**
   * Optionally disables closing the tour on mask click
   */
  disableCloseOnClick: PropTypes.bool,

  /**
   * Optionally provide a callback that handles receiving an update function. Can be used to listen
   * for events and recalculate the tour's position when those events fire. The callback will be
   * passed `update` as an argument.
   */
  setUpdateListener: PropTypes.func,

  /**
   * Optionally provide a callback intended to remove the listener set by `setUpdateListener`.
   * The callback will be passed `update` as an argument. Should only and always be used with `setUpdateListener`.
   */
  removeUpdateListener: PropTypes.func,

  /**
   * Optionally specify whether the tour is active or not. If specified, the tour will act as
   * a controlled component, and will defer to this prop when closing.
   */
  isOpen: PropTypes.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: PropTypes.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: PropTypes.bool,

  /**
   * Optionally allow the tooltip to be flipped over, exposing secondary content on the back side.
   */
  enableFlip: PropTypes.bool,

  /**
   * Secondary Title, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedTitle: PropTypes.string,

  /**
   * Secondary body content, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedDescription: PropTypes.string,

  /**
   * Supports an alternative use case for the flipped case where it will first flip to that face and then close
   * on second click.
   */
  flipBeforeClose: PropTypes.bool,

  /**
   * Accessibility label text for the "close" button
   */
  closeButtonAriaLabel: PropTypes.string,

  /**
   * Accessibility label text for the "flip" button
   */
  flipButtonAriaLabel: PropTypes.string,

  /**
   * Optional selector to explicitly define where the tour components should be rendered in the DOM.
   * This impacts scrolling/scoping, and should only be used if absolutely necessary.
   */
  rootSelector: PropTypes.string
};
export default Tour;