"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _walktour = require("@rocketsoftware/walktour");

var _TourTooltip = _interopRequireDefault(require("../TourTooltip"));

var _propTypes = _interopRequireDefault(require("prop-types"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _slicedToArray(arr, i) { return _arrayWithHoles(arr) || _iterableToArrayLimit(arr, i) || _nonIterableRest(); }

function _nonIterableRest() { throw new TypeError("Invalid attempt to destructure non-iterable instance"); }

function _iterableToArrayLimit(arr, i) { var _arr = []; var _n = true; var _d = false; var _e = undefined; try { for (var _i = arr[Symbol.iterator](), _s; !(_n = (_s = _i.next()).done); _n = true) { _arr.push(_s.value); if (i && _arr.length === i) break; } } catch (err) { _d = true; _e = err; } finally { try { if (!_n && _i["return"] != null) _i["return"](); } finally { if (_d) throw _e; } } return _arr; }

function _arrayWithHoles(arr) { if (Array.isArray(arr)) return arr; }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

var Tour = function Tour(_ref) {
  var flippedTitle = _ref.flippedTitle,
      flippedDescription = _ref.flippedDescription,
      enableFlip = _ref.enableFlip,
      flipBeforeCloseProp = _ref.flipBeforeClose,
      onClose = _ref.onClose,
      other = _objectWithoutProperties(_ref, ["flippedTitle", "flippedDescription", "enableFlip", "flipBeforeClose", "onClose"]);

  var _useState = (0, _react.useState)(false),
      _useState2 = _slicedToArray(_useState, 2),
      flipped = _useState2[0],
      setFlipped = _useState2[1];

  return _react.default.createElement(_walktour.Walktour, _extends({}, other, {
    customCloseFunc: function customCloseFunc(logic) {
      if (onClose) {
        onClose(logic.stepIndex);
      }

      logic.close();
    },
    customTooltipRenderer: function customTooltipRenderer(logic) {
      var _logic$stepContent = logic.stepContent,
          title = _logic$stepContent.title,
          description = _logic$stepContent.description,
          disableNext = _logic$stepContent.disableNext,
          disablePrev = _logic$stepContent.disablePrev,
          hideNext = _logic$stepContent.hideNext,
          hidePrev = _logic$stepContent.hidePrev,
          hideClose = _logic$stepContent.hideClose,
          nextLabel = _logic$stepContent.nextLabel,
          prevLabel = _logic$stepContent.prevLabel,
          flipBeforeClose = _logic$stepContent.flipBeforeClose;
      return _react.default.createElement(_TourTooltip.default, _extends({}, enableFlip && {
        enableFlip: true,
        flipped: flipped,
        onFlip: function onFlip() {
          return setFlipped(!flipped);
        }
      }, {
        flippedTitle: flippedTitle,
        flippedDescription: flippedDescription
      }, other, {
        flipBeforeClose: flipBeforeClose || flipBeforeCloseProp,
        onNext: logic.next,
        onPrev: logic.prev,
        onClose: logic.close,
        description: description,
        title: title,
        disableNext: disableNext,
        disablePrev: disablePrev,
        hideNext: hideNext,
        hidePrev: hidePrev,
        hideClose: hideClose,
        nextLabel: nextLabel,
        prevLabel: prevLabel
      }));
    }
  }));
};

Tour.propTypes = {
  /**
   * An array of steps that the tour should follow
   */
  steps: _propTypes.default.arrayOf(_propTypes.default.shape({
    selector: _propTypes.default.string,
    description: _propTypes.default.string.isRequired,
    title: _propTypes.default.string,
    nextLabel: _propTypes.default.string,
    prevLabel: _propTypes.default.string,
    disableNext: _propTypes.default.bool,
    disablePrev: _propTypes.default.bool,
    hideNext: _propTypes.default.bool,
    hidePrev: _propTypes.default.bool,
    hideClose: _propTypes.default.bool,
    customNextFunc: _propTypes.default.func,
    customPrevFunc: _propTypes.default.func,
    disableAutoScroll: _propTypes.default.bool,
    disableSmoothScroll: _propTypes.default.bool,
    movingTarget: _propTypes.default.bool,
    maskPadding: _propTypes.default.number,
    tooltipSeparation: _propTypes.default.number,

    /**
     * Optionally cause the tour to advance to the next step upon clicking the targeted element.
     * Only buttons are supported.
     */
    nextOnTargetClick: _propTypes.default.bool,

    /**
     * Validate before advancing the tour after clicking a button. Expects a promise resolving to a boolean.
     */
    validateNextOnTargetClick: _propTypes.default.func,
    orientationPreferences: _propTypes.default.oneOf(['east', 'east-north', 'east-south', 'south', 'south-east', 'south-west', 'west', 'west-north', 'west-south', 'north', 'north-east', 'north-west']),

    /**
     * If specified, the tour will try to target and position with respect to an element that is outside
     * of its parent container. The tour is still bound to its container, so this should only be used
     * sparingly in situations where it cannot be avoided.
     */
    allowForeignTarget: _propTypes.default.bool
  })).isRequired,

  /** Optionally specify a custom close function for the entire tour. Passed the current step index as a param.
   */
  onClose: _propTypes.default.func,

  /**
   * Optionally specify the starting step. If conditionally rendering ({showTour && <Tour... />})
   * this can be used to resume from a particular step, even after unmounting.
   */
  initialStepIndex: _propTypes.default.number,

  /**
   * Optionally specify whether the tour should update upon changes to the target's size or position.
   */
  movingTarget: _propTypes.default.bool,

  /**
   * Optional identifier to differentiate between multiple tours on the same page.
   */
  identifier: _propTypes.default.string,

  /**
   * Optionally specify whether the mask should be disabled
   */
  disableMask: _propTypes.default.bool,

  /**
   * Optionally disable automatic scrolling
   */
  disableAutoScroll: _propTypes.default.bool,

  /**
   * Optionally disable smooth scrolling
   */
  disableSmoothScroll: _propTypes.default.bool,

  /**
   * Optionally disables closing the tour on mask click
   */
  disableCloseOnClick: _propTypes.default.bool,

  /**
   * Optionally provide a callback that handles receiving an update function. Can be used to listen
   * for events and recalculate the tour's position when those events fire. The callback will be
   * passed `update` as an argument.
   */
  setUpdateListener: _propTypes.default.func,

  /**
   * Optionally provide a callback intended to remove the listener set by `setUpdateListener`.
   * The callback will be passed `update` as an argument. Should only and always be used with `setUpdateListener`.
   */
  removeUpdateListener: _propTypes.default.func,

  /**
   * Optionally specify whether the tour is active or not. If specified, the tour will act as
   * a controlled component, and will defer to this prop when closing.
   */
  isOpen: _propTypes.default.bool,

  /**
   * Optionally specify whether the "next"" button should be hidden
   */
  hideNext: _propTypes.default.bool,

  /**
   * Optionally specify whether the "previous" button should be hidden
   */
  hidePrev: _propTypes.default.bool,

  /**
   * Optionally allow the tooltip to be flipped over, exposing secondary content on the back side.
   */
  enableFlip: _propTypes.default.bool,

  /**
   * Secondary Title, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedTitle: _propTypes.default.string,

  /**
   * Secondary body content, visible when the tooltip is flipped. Access flip functionality with "enableFlip"
   */
  flippedDescription: _propTypes.default.string,

  /**
   * Supports an alternative use case for the flipped case where it will first flip to that face and then close
   * on second click.
   */
  flipBeforeClose: _propTypes.default.bool,

  /**
   * Accessibility label text for the "close" button
   */
  closeButtonAriaLabel: _propTypes.default.string,

  /**
   * Accessibility label text for the "flip" button
   */
  flipButtonAriaLabel: _propTypes.default.string,

  /**
   * Optional selector to explicitly define where the tour components should be rendered in the DOM.
   * This impacts scrolling/scoping, and should only be used if absolutely necessary.
   */
  rootSelector: _propTypes.default.string
};
var _default = Tour;
exports.default = _default;